@@ -11,7 +11,7 @@ from awxkit.cli.format import FORMATTERS, format_response, add_authentication_ar
 from awxkit.cli.utils import CustomRegistryMeta, cprint
 
 
-CONTROL_RESOURCES = ['ping', 'config', 'me', 'metrics']
+CONTROL_RESOURCES = ['ping', 'config', 'me', 'metrics', 'mesh_visualizer']
 
 DEPRECATED_RESOURCES = {
     'ad_hoc_commands': 'ad_hoc',
@@ -99,7 +99,7 @@ class Login(CustomCommand):
         else:
             fmt = client.get_config('format')
             if fmt == 'human':
-                print('export TOWER_OAUTH_TOKEN={}'.format(token))
+                print('export CONTROLLER_OAUTH_TOKEN={}'.format(token))
             else:
                 print(to_str(FORMATTERS[fmt]({'token': token}, '.')).strip())
 
